package
Version:
v1.10.5
Opens a new window with list of versions in this module.
Published: Jun 30, 2025
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SendLicenseMail(targetEmail, license string) (err error)
func SendResetPwdValidateMail(targetEmail, authCode string) (seqNo string, err error)
type Mailer struct {
Code string `yaml:"code"`
Subject string `yaml:"subject"`
Content string `yaml:"content"`
Type string `yaml:"type"`
Dialer *gomail.Dialer `json:"-" yaml:"-"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.